@@ -13,15 +13,16 @@ A wrapper around the other loading utilities
 import os.path
 import glob
 from . import load_mcords  # needs to be imported first and alone due to opaque h5py/netcdf4 error
-from . import load_gssi, load_pulse_ekko, load_gprMax, load_olaf, load_segy, load_UoA_mat
-from . import load_delores, load_osu, load_stomat, load_ramac, load_bsi
+from . import load_gssi, load_pulse_ekko, load_gprMax, load_olaf, load_segy, load_UoA
+from . import load_delores, load_osu, load_stomat, load_ramac, load_bsi, load_tek
 from ..RadarData import RadarData
 
 # This should be updated as new functionality arrives
 # executables that accept multiple ftypes should use this
 # to figure out what the available options are
-FILETYPE_OPTIONS = ['mat', 'pe', 'gssi','stomat', 'gprMax', 'gecko', 'segy',
-                    'mcords_mat', 'mcords_nc', 'UoA_mat', 'ramac', 'bsi', 'delores', 'osu', 'ramac']
+FILETYPE_OPTIONS = ['mat', 'pe', 'gssi', 'stomat', 'gprMax', 'gecko', 'segy', 'mcords_mat',
+                    'mcords_nc', 'UoA_mat', 'UoA_h5', 'ramac', 'bsi', 'delores', 'osu',
+                    'ramac', 'tek']
 
 
 def load(filetype, fns_in, channel=1, t_srs=None, s_srs=None, *args, **kwargs):
@@ -52,9 +53,9 @@ def load(filetype, fns_in, channel=1, t_srs=None, s_srs=None, *args, **kwargs):
             # If a pulse ekko project file is input. We need to partition it first.
             if os.path.splitext(fn)[-1] == '.GPZ':
                 bn_pe = os.path.splitext(fn)[0]
-                print(fn,'is a Pulse Ekko project file.\n'+\
-                    'We will partition it into the respective data and header files at ./'+\
-                    bn_pe)
+                print(fn, 'is a Pulse Ekko project file.\n' +
+                      'We will partition it into the respective data and header files at ./' +
+                      bn_pe)
                 if not os.path.isdir(bn_pe):
                     os.mkdir(bn_pe)
                 os.rename(fn, os.path.join(bn_pe, fn))
@@ -71,11 +72,11 @@ def load(filetype, fns_in, channel=1, t_srs=None, s_srs=None, *args, **kwargs):
                 try:
                     dat.append(load_pulse_ekko.load_pe(fn))
                 except IOError:
-                    print('Could not load ',fn, 'as a Pulse Ekko file.')
+                    print('Could not load ', fn, 'as a Pulse Ekko file.')
     elif filetype == 'mat':
         dat = [RadarData(fn) for fn in fns_in]
     elif filetype == 'stomat':
-        dat = [load_stomat.load_stomat(fn) for fn in fns_in]
+        dat = [load_stomat.load_stomat(fn, **kwargs) for fn in fns_in]
     elif filetype == 'gprMax':
         if load_gprMax.H5:
             dat = [load_gprMax.load_gprMax(fn) for fn in fns_in]
@@ -111,21 +112,28 @@ def load(filetype, fns_in, channel=1, t_srs=None, s_srs=None, *args, **kwargs):
             raise ImportError('You need netCDF4 in order to read the MCoRDS files')
     elif filetype == 'mcords_mat':
         dat = [load_mcords.load_mcords_mat(fn) for fn in fns_in]
-    elif filetype == 'UoA_mat':
-        if load_UoA_mat.H5:
+    elif filetype in ['UoA_mat', 'UoA_h5']:
+        if load_UoA.H5:
             if 'gps_offset' in kwargs:
                 gps_offset = kwargs['gps_offset']
             else:
                 gps_offset = 0.0
-            dat = [load_UoA_mat.load_UoA_mat(fn, gps_offset=gps_offset) for fn in fns_in]
+            if filetype == 'UoA_mat':
+                dat = [load_UoA.load_UoA_mat(fn, gps_offset=gps_offset) for fn in fns_in]
+            elif filetype == 'UoA_h5':
+                dat = []
+                for fn in fns_in:
+                    dat += load_UoA.load_UoA_h5(fn, gps_offset=gps_offset)
         else:
-            raise ImportError('You need h5py for UoA_mat')
+            raise ImportError('You need h5py for UoA')
     elif filetype == 'delores':
         dat = [load_delores.load_delores(fn, channel=channel) for fn in fns_in]
     elif filetype == 'osu':
         dat = [load_osu.load_osu(fns_in)]
     elif filetype == 'ramac':
         dat = [load_ramac.load_ramac(fn) for fn in fns_in]
+    elif filetype == 'tek':
+        dat = [load_tek.load_tek(fn) for fn in fns_in]
     else:
         raise ValueError('Unrecognized filetype')
 
@@ -145,6 +153,7 @@ def load(filetype, fns_in, channel=1, t_srs=None, s_srs=None, *args, **kwargs):
 
     return dat
 
+
 def load_and_exit(filetype, fns_in, channel=1, t_srs=None, s_srs=None, o=None, *args, **kwargs):
     """Load a list of files of a certain type, save them as StODeep mat files, exit
 
@@ -185,6 +194,7 @@ def load_and_exit(filetype, fns_in, channel=1, t_srs=None, s_srs=None, o=None, *
             rd_list = load(filetype, fn_i, channel=channel, t_srs=t_srs, s_srs=s_srs, *args, **kwargs)
             _save(rd_list, outpath=o)
 
+
 def _save(rd_list, outpath=None):
     """Save a list of RadarData objects with optional output directory."""
     if outpath is not None:
